# CWT-Seismology
This code is optimized to compute the Characteristics Functions using the complex/real 
Morlet Wavelet, see references. It can also be used to detect signals in the waveform. 

Currently, the algorithm is also implemented in the 
[Integrated Seismic Programs](https://github.com/rcabdia/ISP/tree/Pyqt5_migration)
(ISP)

# Authors

[Roberto Cabieces](https://github.com/rcabdia), [Thiago C. Junqueira](https://github.com/junqfisica)

# References

Application to Ocean Bottom Seismometers, Geophysical Journal International, https://doi.org/10.1093/gji/ggaa427
